@@ -1,28 +1,28 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides support for a flat review find."""
 
-__id__        = "$Id: find.py 3109 2007-10-19 04:01:04Z joanied $"
-__version__   = "$Revision: 3109 $"
-__date__      = "$Date: 2007-10-19 00:01:04 -0400 (Fri, 19 Oct 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 
@@ -32,7 +32,6 @@ import re
 import debug
 import flat_review
 import orca_state
-import speech
 
 from orca_i18n import _    # for gettext support
 
@@ -251,6 +250,7 @@ class SearchQuery:
                     # Then we're at the screen's edge.
                     #
                     if self.windowWrap and not wrappedYet:
+                        script = orca_state.activeScript
                         doneWithLine = False
                         wrappedYet = True
                         if self.searchBackwards:
@@ -263,7 +263,7 @@ class SearchQuery:
                             # direction is wrapping from the top of
                             # the window down to the bottom.
                             #
-                            speech.speak(_("Wrapping to Bottom"))
+                            script.presentMessage(_("Wrapping to Bottom"))
                             moved = context.goPrevious( \
                                     flat_review.Context.LINE, \
                                     flat_review.Context.WRAP_ALL)
@@ -278,7 +278,7 @@ class SearchQuery:
                             # direction is wrapping from the bottom of
                             # the window up to the top.
                             #
-                            speech.speak(_("Wrapping to Top"))
+                            script.presentMessage(_("Wrapping to Top"))
                             moved = context.goNext( \
                                     flat_review.Context.LINE, \
                                     flat_review.Context.WRAP_ALL)
